texture2D gColorEdgeDetectSourceImage;
texture2D gColorEdgeDetectMaterial;

sampler ColorEdgeDetectSampler = sampler_state
{
	Texture = <gColorEdgeDetectMaterial>;
	
	AddressU = Clamp;
	AddressV = Clamp;
	
	MagFilter = None;
    MagFilter = None;
    MipFilter = None;
};

sampler MaterialSampler = sampler_state
{
	Texture = <gColorEdgeDetectSourceImage>;
	
	AddressU = Clamp;
	AddressV = Clamp;
	
	MagFilter = None;
    MagFilter = None;
    MipFilter = None;
};

struct InputPresentPS
{
	float4	posOut		: POSITION0;
    float2  texOut		: TEXCOORD0;
	float3	worldPosOut : TEXCOORD1;
	float3	normOut		: TEXCOORD2;
};

float2 PixelKernel[4] =
{
    { 0,  .02},
    { .02,  0},
    { 0, -.02},
    {-.02,  0}
};

float2 TexelKernel[4] =
{
    { 0,  1.0f/1024.0f},
    { 1.0f/768.0f,  0},
    { 0, -1.0f/1024.0f},
    {-1.0f/768.0f,  0}
};

/*
float2 TexelKernel[4]
<
	string ConvertPixelsToTexels = "PixelKernel";
>;
*/

float3 LuminanceConv = { 0.1f, 0.1f, 0.1f};

float4 psPresent(InputPresentPS inPS) : COLOR0
{
    float4 Orig = tex2D( ColorEdgeDetectSampler, inPS.texOut );

    float4 Sum = 0;

    for( int i = 0; i < 4; i++ )
    {
        Sum += ( abs( Orig - tex2D( ColorEdgeDetectSampler, inPS.texOut + TexelKernel[i] ) ) - 0.5f ) * 1.2 + 0.5f;
    }

    return saturate( dot( LuminanceConv, Sum ) ) * 5;
};


technique ColorEdgeDetectTechnique
{
	pass p0
	{
		VertexShader = NULL;
		PixelShader = compile ps_2_0 psPresent();

        AlphaBlendEnable = False; 
        StencilEnable = False;
        ZEnable = False;
	}
}
