// Foreground texture
texture2D gCurrentImageHoriz;

// Foreground sampler
sampler2D gImageSampler = sampler_state
{
    Texture = <gCurrentImageHoriz>;
	MagFilter = None;
	MinFilter = None;
	MipFilter = None;
};

// Pixel width in texels
float pixelWidth = 0.002f;

float PixelKernel[13] =
{
    -6,
    -5,
    -4,
    -3,
    -2,
    -1,
     0,
     1,
     2,
     3,
     4,
     5,
     6,
};

static const float BlurWeights[13] = 
{
    0.002216,
    0.008764,
    0.026995,
    0.064759,
    0.120985,
    0.176033,
    0.199471,
    0.176033,
    0.120985,
    0.064759,
    0.026995,
    0.008764,
    0.002216,
};

struct InputBuildVS
{
	float3 posIn  : POSITION0;
	float2 texIn  : TEXCOORD0;
	float3 normIn : NORMAL0;
	float3 tanIn  : TANGENT0;
	float3 binIn  : BINORMAL0;
};

struct OutputBuildVS
{
	float4	posOut		: POSITION0;
    float2  texOut		: TEXCOORD0;
	float3	worldPosOut : TEXCOORD1;
	float3	normOut		: TEXCOORD2;
};

struct InputPresentPS
{
	float4	posOut		: POSITION0;
    float2  texOut		: TEXCOORD0;
	float3	worldPosOut : TEXCOORD1;
	float3	normOut		: TEXCOORD2;
};

OutputBuildVS vsBuild(InputBuildVS inVS)
{
	OutputBuildVS outVS = (OutputBuildVS)0;
	outVS.posOut = float4(inVS.posIn,1);
	outVS.texOut = inVS.texIn;
	outVS.normOut = inVS.normIn;
	
	return outVS;
};

// Effect function
float4 psPresent(InputPresentPS inPS) : COLOR0
{
    // Apply surrounding pixels
    float4 color = 0;
    float2 samp = inPS.texOut;
    samp.y = inPS.texOut.y;

    for (int i = 0; i < 13; i++)
    {
        samp.x = inPS.texOut.x + PixelKernel[i] * pixelWidth;
        color += tex2D(gImageSampler, samp.xy) * BlurWeights[i];
    }

    return color;
}

technique GaussianBlurHorizontalTechnique
{
    pass p0
    {
        VertexShader = compile vs_3_0 vsBuild();
        PixelShader = compile ps_3_0 psPresent();
        
        AlphaBlendEnable = False; 
        StencilEnable = False;
        ZEnable = False;
    }
}

