uniform extern texture  gTexture;

// Our samplers for texturing
sampler TexSampler = sampler_state
{
	Texture = <gTexture>;
	MinFilter = Anisotropic;
	MagFilter = LINEAR;
	MipFilter = LINEAR;
	MaxAnisotropy = 8;
	AddressU  = WRAP;
	AddressV  = WRAP;
};
 
// Output structure
struct OutputVS
{
    float4 posS    : POSITION0;
    float2 texC    : TEXCOORD0;
}; 
 
// Screen Vertex Shader
OutputVS ScreenVS (float3 posIn : POSITION0,
                   float2 texIn : TEXCOORD0)
{
  // Zero out our output
  OutputVS outVS = (OutputVS)0;

  outVS.posS = float4(posIn,1.0f);
  outVS.texC = texIn;

  return outVS;
}

// Screen Pixel Shader
float4 ScreenPS(float2 texIn : TEXCOORD0) : COLOR
{
  return tex2D(TexSampler,texIn);
}

// Quad Techniques
technique Screen2DTechnique
{
	pass P0
	{
		// Specify the vertex and pixel shader associated with this pass.
		vertexShader = compile vs_2_0 ScreenVS();
		pixelShader  = compile ps_2_0 ScreenPS();
		
		// Settings  
		AlphaBlendEnable = True;
		SrcBlend = SrcAlpha;
		DestBlend = InvSrcAlpha;
		CullMode = None;		
	}
}
