uniform extern float4x4 gWVP;
uniform extern texture  gEnvMap;

sampler EnvMapS = sampler_state
{
    Texture   = <gEnvMap>;
    AddressU  = WRAP;
    AddressV  = WRAP;
};

// Output structure
struct OutSkyVS
{
    float4 posH   : POSITION0;
    float3 tex    : TEXCOORD0;
};

// Function to force grayscale
float3 grayscale(float3 color)
{
  //Average the rgb and set for all
  float col = (color.r + color.g + color.b)/3.0f;
  return float3(col,col,col);
}

OutSkyVS SkyVS(float3 posL : POSITION0)
{
  // Zero out our output
  OutSkyVS outVS = (OutSkyVS)0;

  // Set z = w so that z/w = 1 (i.e., skydome always on far plane).
  outVS.posH = mul(float4(posL, 1.0f), gWVP).xyww; 
    
  // Use skymesh vertex position, in local space, as index into cubemap. 
  outVS.tex = posL;
    
  return outVS;
}

float4 SkyPS(float3 envTex : TEXCOORD0) : COLOR
{
    return float4(texCUBE(EnvMapS, envTex));
}

technique SkyTech
{
  pass P0
  {
    vertexShader = compile vs_2_0 SkyVS();
    pixelShader  = compile ps_2_0 SkyPS();
    
	CullMode = CW;
	ZFunc = Always; // Always write sky to depth buffer
	AlphaBlendEnable = False;
	StencilEnable = True;
	StencilFunc   = Equal;
	StencilPass   = Replace;
    StencilRef    = 0; // clear to zero
  }
}

